@@ -22,6 +22,7 @@
 import collections
 import json
 
+from majormode.perseus.constant.account import AccountType
 from majormode.perseus.constant.obj import ObjectStatus
 from majormode.perseus.constant.contact import ContactName
 from majormode.perseus.model import obj
@@ -556,7 +557,7 @@ class ContactService(BaseRdbmsService):
         """
         from majormode.perseus.service.account.account_service import AccountService
 
-        assert not (has_been_verified and to_be_verified), 'Conflicted values'
+        assert not (has_been_verified and to_be_verified), "Conflicted values"
 
         # Check whether this contact has been already added to this account.
         account = AccountService().get_account(
@@ -570,22 +571,21 @@ class ContactService(BaseRdbmsService):
 
         # Check whether this contact would been added to another user account
         # and wether it would have been verified.
-        (is_available, is_verified) = self.is_contact_available(contact)
+        (is_available, is_verified) = self.is_contact_available(contact, connection=connection)
         if not is_available and is_verified:
-            raise self.ContactAlreadyUsedException('Another user has already verified this contact information')
+            raise self.ContactAlreadyUsedException("Another user has already verified this contact information")
 
         # Check whether this contact information can been stated verified.
         if contact.is_verified and not has_been_verified and account.account_type not in [
-                AccountService.AccountType.botnet,
-                AccountService.AccountType.sns,
-                AccountService.AccountType.test
+                AccountType.botnet,
+                AccountType.sns,
+                AccountType.test
             ]:
-            raise self.InvalidArgumentException('A contact cannot be stated as verified without passing a challenge process')
+            raise self.InvalidArgumentException("A contact cannot be stated as verified without passing a challenge process")
 
         # Add this contact information to the specified user account, and
         # generate a verification request if required.
-        with self.acquire_rdbms_connection( auto_commit=True, connection=connection) as connection:
-
+        with self.acquire_rdbms_connection(auto_commit=True, connection=connection) as connection:
             # If verified, disable this contact information from any other user
             # account, and cancel any request that would have been generated to
             # verify this contact information.
@@ -651,7 +651,7 @@ class ContactService(BaseRdbmsService):
 
             # If this contact information needs to be verified, generate a
             # verification request that will be sent to the user.
-            if to_be_verified and account.account_type == AccountService.AccountType.standard:
+            if to_be_verified and account.account_type == AccountType.standard:
                 self.request_contact_verification(
                     contact,
                     account_id=account_id,
@@ -1095,9 +1095,9 @@ class ContactService(BaseRdbmsService):
     #                         payload={ 'contact': (name, value) })
     #
     #         if is_verified and account.account_type not in [
-    #                 AccountService.AccountType.botnet,
-    #                 AccountService.AccountType.sns,
-    #                 AccountService.AccountType.test]:
+    #                 AccountType.botnet,
+    #                 AccountType.sns,
+    #                 AccountType.test]:
     #             raise self.InvalidArgumentException('Contact of account other than botnet, SNS, and test cannot be stated as verified')
     #
     #         connection.execute("""
