@@ -67,14 +67,14 @@ class HttpRequestLog:
             dispatch_duration,
             exception=None):
         """
-        Build a ``HttpRequestLog`` instance providing detailed information
+        Build a `HttpRequestLog` instance providing detailed information
         about the processing of a HTTP request that a client application sent
         to the platform.
 
 
-        :param request: A ``HttpRequest`` instance.
+        :param request: A `HttpRequest` instance.
 
-        :param response: A ``HttpResponse`` instance.
+        :param response: A `HttpResponse` instance.
 
         :param execution_duration: The time spent in processing the client's
             HTTP request.
@@ -166,7 +166,7 @@ class HttpRequest:
         the HTTP request processor.
         """
 
-    class HttpRequestUploadedFile(object):
+    class HttpRequestUploadedFile:
         """
         Represent a file that has been uploaded.
         """
@@ -210,6 +210,87 @@ class HttpRequest:
         def file_name(self):
             return self._file_name
 
+    class ArgumentObject:
+        """
+
+        """
+        @staticmethod
+        def _get_argument(
+                payload,
+                argument_name,
+                data_type=None,
+                default_value=None,
+                enumeration=None,
+                is_required=True,
+                item_data_type=None,
+                object_class=None):
+            """
+            Return the value of an argument contained in the JSON expression
+
+
+            :param payload: A JSON expression.
+
+            :param argument_name: Name of the argument to return the value.
+
+            :param default_value: default value to return if the argument was
+                optional and not defined within the HTTP request.
+
+            :param enumeration: An enumeration inheriting from `Enum`, when the
+                argument `data_type` is `ArgumentDataType.enumeration`.
+
+            :param is_required: Indicate whether this argument is mandatory, i.e.
+                it MUST be provided in the HTTP request, and if not provided, the
+                function will raise the exception `MissingArgumentException`.
+
+            :param item_data_type: When the argument to return the value is of
+                data type `ArgumentType.list`, the caller can specify the data
+                type of the items that this list contains.
+
+            :param object_class: Python class to be used to instantiate a new
+                object from the JSON value of the given argument when the
+                specified data type of this argument is `object`.  This Python
+                class MUST implement a static method `from json` that returns an
+                instance of this class providing a JSON expression.
+
+
+            :return: The casted value of the argument.
+
+
+            :raise MissingArgumentException: If the JSON expression doesn't
+                contain the specified argument while this argument is required.
+            """
+            if not isinstance(payload, dict):
+                raise ValueError("The argument 'payload' MUST be a dictionary")
+
+            if is_required and argument_name not in payload:
+                raise HttpRequest.MissingArgumentException(f'Required argument "{argument_name}" is not passed')
+
+            argument_value = payload.get(argument_name) or default_value
+
+            casted_argument_value = HttpRequest.cast_value(
+                argument_name,
+                argument_value,
+                argument_passing=HttpRequest.ArgumentPassing.message_body,
+                data_type=data_type or HttpRequest.ArgumentDataType.string,
+                enumeration=enumeration,
+                item_data_type=item_data_type or HttpRequest.ArgumentDataType.string,
+                object_class=object_class)
+
+            return casted_argument_value
+
+        @staticmethod
+        def from_json(payload):
+            """
+            Build an object with a JSON expression
+
+
+            :param payload: A JSON expression.
+
+
+            :return: An object built from the JSON expression
+            """
+            raise NotImplementedError()
+
     ArgumentDataType = Enum(
         'boolean',
         'date',
@@ -251,15 +332,15 @@ class HttpRequest:
             body=None,
             uploaded_files=None):
         """
-        Build an instance ``HttpRequest`` representing the HTTP request that a
+        Build an instance `HttpRequest` representing the HTTP request that a
         client application sent to the platform.
 
 
-        :note: The method ``_prepare_`` MUST be called to complete the
+        :note: The method `_prepare_` MUST be called to complete the
             instantiation of this object.
 
 
-        :param http_method: An instance ``HttpMethod`` that indicates the HTTP
+        :param http_method: An instance `HttpMethod` that indicates the HTTP
             method of this request.
 
         :param uri: Uniform Resource Identifier that names a resource of the
@@ -275,9 +356,9 @@ class HttpRequest:
             application that initiates this HTTP request.
 
         :param body: Content of the message body of the HTTP request when the
-            HTTP method is ``POST`` or ``PUT``.
+            HTTP method is `POST` or `PUT`.
 
-        :param uploaded_files: A list of instances ``HttpRequestUploadedFile``
+        :param uploaded_files: A list of instances `HttpRequestUploadedFile`
             mapping the files that the client application has uploaded to
             the platform along the HTTP request.
         """
@@ -302,7 +383,7 @@ class HttpRequest:
         # "gzip" method.
         #
         # To decompress gzipped data with zlib, the windowBits parameter must
-        # be 16 + MAX_WBITS (cf. function ``deflateInit2``;
+        # be 16 + MAX_WBITS (cf. function `deflateInit2`;
         # http://www.zlib.net/manual.html]::
         #
         #   windowBits can also be greater than 15 for optional gzip encoding.
@@ -326,22 +407,30 @@ class HttpRequest:
             content_type_parts = [part.strip() for part in content_type.split(';')]
             media_type, encoding = content_type_parts if len(content_type_parts) == 2 else (content_type_parts[0], None)
 
+        print("########### MESSAGE BODY ##########")
+        print(self.raw_body)
+        print(content_type)
+        print(content_type and media_type)
+
         self.body = None if self.raw_body is None \
             else json.loads(self.raw_body) if content_type and media_type == 'application/json' \
             else self.raw_body
 
+        print("########### MESSAGE BODY ##########")
+        print(self.body)
+
     # def _prepare(self):
     #     """
     #     Complete the instantiation of the HTTP request object.  This method
-    #     MUST be called once the ``HttpRequest`` instance has been built.
+    #     MUST be called once the `HttpRequest` instance has been built.
     #
     #     This function is responsible for uncompressing gzip content of the
-    #     HTTP request message body when the HTTP method is ``PUT`` or ``POST``
-    #     and the content encoding has been indicated as of ``gzip``.
+    #     HTTP request message body when the HTTP method is `PUT` or `POST`
+    #     and the content encoding has been indicated as of `gzip`.
     #
     #     This function is responsible for converting the string content (cf.
-    #     member ``body``) of the HTTP request's message body into a JSON object
-    #     when the content type has been indicated as of ``application/json``.
+    #     member `body`) of the HTTP request's message body into a JSON object
+    #     when the content type has been indicated as of `application/json`.
     #
     #     :raise Exception: if decompression issue occurs or if JSON string
     #            representation is not conform to the JSON specification.
@@ -350,7 +439,7 @@ class HttpRequest:
     #     # "gzip" method.
     #     #
     #     # To decompress gzipped data with zlib, the windowBits parameter must
-    #     # be 16 + MAX_WBITS (cf. function ``deflateInit2``;
+    #     # be 16 + MAX_WBITS (cf. function `deflateInit2`;
     #     # http://www.zlib.net/manual.html]::
     #     #
     #     #   windowBits can also be greater than 15 for optional gzip encoding.
@@ -520,20 +609,20 @@ class HttpRequest:
             query string or the message body.  The default argument passing
             depends on the HTTP method of the request:
 
-            * ``DELETE``: query string
+            * `DELETE`: query string
 
-            * ``GET``: query string
+            * `GET`: query string
 
-            * ``POST``: message body
+            * `POST`: message body
 
-            * ``PUT``: message body
+            * `PUT`: message body
 
             When the value of the argument is passed in the message body, the
             function expects the message body to be a JSON dictionary, and the
             argument's name to be a root key of this dictionary.
 
         :param data_type: data type of the value of this argument as one
-            defined in the enumeration ``HttpRequest.ArgumentDataType``.  The
+            defined in the enumeration `HttpRequest.ArgumentDataType`.  The
             function might performs some check to ensure that the value of this
             argument corresponds to the specified data type.
 
@@ -545,16 +634,16 @@ class HttpRequest:
 
         :param is_required: Indicate whether this argument is mandatory, i.e.
             it MUST be provided in the HTTP request, and if not provided, the
-            function will raise the exception ``MissingArgumentException``.
+            function will raise the exception `MissingArgumentException`.
 
         :param item_data_type: When the argument to return the value is of
-            data type ``ArgumentType.list``, the caller can specify the data
+            data type `ArgumentType.list`, the caller can specify the data
             type of the items that this list contains.
 
         :param object_class: Python class to be used to instantiate a new
             object from the JSON value of the given argument when the
-            specified data type of this argument is ``object``.  This Python
-            class MUST implement a static method ``from json`` that returns an
+            specified data type of this argument is `object`.  This Python
+            class MUST implement a static method `from json` that returns an
             instance of this class providing a JSON expression.
 
 
@@ -595,6 +684,10 @@ class HttpRequest:
         # the message body, depending on the argument passing.
         is_argument_defined = False
 
+        print("########## ARGUMENT PASSING ##########")
+        print(str(argument_passing))
+        print(self.body)
+
         if argument_passing == HttpRequest.ArgumentPassing.query_string:
             if name in self.arguments:
                 is_argument_defined = True
@@ -608,8 +701,9 @@ class HttpRequest:
             if not isinstance(self.body, dict):
                 raise HttpRequest.InvalidMessageBodyException()
 
-            is_argument_defined = True
-            value = self.body.get(name)
+            is_argument_defined = name in self.body
+            if is_argument_defined:
+                value = self.body.get(name)
 
         # Check whether this argument is required while the client application
         # didn't pass this argument with the HTTP request.
@@ -656,10 +750,10 @@ class HttpRequest:
 
         :param is_required: Indicate whether this header is mandatory, i.e.
             it MUST be provided in the HTTP request, and if not provided, the
-            function will raise the exception ``MissingHeaderException``.
+            function will raise the exception `MissingHeaderException`.
 
         :param item_data_type: When the header to return the value is of
-            data type ``ArgumentType.list``, the caller can specify the data
+            data type `ArgumentType.list`, the caller can specify the data
             type of the items that this list contains.
 
 
@@ -766,15 +860,15 @@ class HttpMethodSpec:
 
 
         :param http_method: One of the supported HTTP 1.1 common methods as
-           defined in the enumeration ``HttpMethod`` of the class `HttpRequest`:
+           defined in the enumeration `HttpMethod` of the class `HttpRequest`:
 
-           * ``HttpMethod.DELETE``
+           * `HttpMethod.DELETE`
 
-           * ``HttpMethod.GET``
+           * `HttpMethod.GET`
 
-           * ``HttpMethod.POST``
+           * `HttpMethod.POST`
 
-           * ``HttpMethod.PUT``
+           * `HttpMethod.PUT`
 
 
         :param uri_pattern: Uniform Resource Identifier (URI) pattern (i.e.,
@@ -1018,10 +1112,10 @@ class HttpRequestHandler:
     Base class of the HTTP request handler that each RESTful API class
     MUST inherit from.
     """
-    # Class member that contains all the ``HttpMethodSpec`` instances that
+    # Class member that contains all the `HttpMethodSpec` instances that
     # the RESTful API application has successfully loaded.
     #
-    # The key corresponds to the hash of ``HttpMethodSpec`` instance while
+    # The key corresponds to the hash of `HttpMethodSpec` instance while
     # the value corresponds to the instance itself.  The key is mostly used
     # by the code responsible for adding declared RESTful methods from
     # Python modules, and making sure that two or more methods are declared
@@ -1136,18 +1230,18 @@ def http_request(
     * At compile time, this decorator registers the wrapped method as the
       handler for the specified Uniform Resource Identifier (URI) pattern
       corresponding to a regular expression and a HTTP method such as
-      ``GET``, ``POST``, ``PUT``, and ``DELETE``.  It checks that no other
+      `GET`, `POST`, `PUT`, and `DELETE`.  It checks that no other
       URI pattern has been register for the specified HTTP method.
 
     * At run time, this decorator performs around processing of the HTTP
     request for which the wrapped method is invoked.  For instance:
 
       * Ensure that the HTTP request has been correctly signed (cf.
-        argument ``signature_enabled``)
+        argument `signature_enabled`)
 
       * Ensure that the HTTP request transports the identification of the
         session of a user on behalf of the wrapped method is called (cf.
-        argument ``authentication_required``)
+        argument `authentication_required`)
 
       * Check that the client application is compatible with the version
         of the server platform's API this client application is
@@ -1158,7 +1252,7 @@ def http_request(
         corresponding to a regular expression, the wrapped method is
         responsible to handle.
 
-    :param http_method: An item of the enumeration ``HttpMethod``.  The
+    :param http_method: An item of the enumeration `HttpMethod`.  The
         selected HTTP method indicates the desired action to be performed
         on the resource identified by the URI.  What this resource
         represents depends on the implementation of the method wrapped.
@@ -1166,7 +1260,7 @@ def http_request(
     :param authentication_required: Indicate whether the wrapped method
         requires the user, on behalf of whom the HTTP request is sent, to
         be authenticated or not.  If `True`, the client application MUST
-        provide the HTTP header field ``X-Authentication``, passing the
+        provide the HTTP header field `X-Authentication`, passing the
         identification of the login session of this user.
 
     :param compatibility_required: Indicate whether the wrapped method
@@ -1177,7 +1271,7 @@ def http_request(
         using a standard tuple of integers: `major.minor.patch`.
 
     :param json_data: Indicate whether the message body of HTTP methods
-        such as ``POST`` and ``PUT`` MUST be a string representation of a
+        such as `POST` and `PUT` MUST be a string representation of a
         JSON expression.
 
     :param sensitive_data: Indicate whether sensitive data could be
@@ -1217,7 +1311,7 @@ def http_request(
         passed to this decorator have incoherent values, etc.
     """
     # Check that the method decorated is bounded to a class that inherits
-    # from ``HttpRequestHandler``.
+    # from `HttpRequestHandler`.
     #
     # @note: it does seem possible to get the class of the method that is
     # decorated such as:
@@ -1330,7 +1424,7 @@ def get_account_session(request, app_id, authentication_required):
     :param authentication_required: Indicate whether the wrapped method
         requires the user, on behalf of whom the HTTP request is sent, to
         be authenticated or not.  If `True`, the client application MUST
-        provide the HTTP header field ``X-Authentication``, passing the
+        provide the HTTP header field `X-Authentication`, passing the
         identification of the login session of this user.
 
 
